@@ -2,14 +2,13 @@ import os
 from functools import wraps
 from fastapi import Request, Body
 
-from magicapi import background_router
-
+from magicapi import app
 
 from magicapi.Globals.G import g
 from magicapi.Models.Task import Task, TaskParams
 
 import inspect
-from fastapi import HTTPException
+from fastapi import HTTPException, APIRouter
 import json
 from datetime import datetime
 
@@ -23,8 +22,9 @@ from magicapi.Decorators.helpers import async_safe
 
 def run_in_background(f):
     router_path = f"/run_in_background/{f.__name__}"
+    new_r = APIRouter()
 
-    @background_router.post(router_path, tags=["background_tasks"])
+    @new_r.post(router_path, tags=["background_tasks"])
     async def endpoint(
         request: Request,
         task_id: str = Body(...),
@@ -60,6 +60,8 @@ def run_in_background(f):
 
         return {"success": True, "message": ""}
 
+    app.include_router(new_r)
+
     @wraps(f)
     def wrapper(*args, **kwargs):
         if not os.getenv("HasDB"):
